@@ -1,20 +1,14 @@
-# this file is copied from external/gable to control-plane/packages/core/python/types/control_plane_types
-# as part of generating oas types. Edits should only be made to the original in external/gable/
-
 from .openapi import SourceType
 
 ALL_SOURCE_TYPES = list(SourceType)
 
 DATABASE_SOURCE_TYPES = [
-    SourceType.postgres,
     SourceType.mysql,
     SourceType.mssql,
+    SourceType.postgres,
 ]
 
-FILE_SOURCE_TYPES = [
-    SourceType.avro,
-    SourceType.protobuf,
-]
+FILE_SOURCE_TYPES = [SourceType.protobuf, SourceType.avro]
 
 STATIC_CODE_ANALYSIS_SOURCE_TYPES = [
     SourceType.python,
