@@ -4,9 +4,10 @@ from enum import Enum
 from typing import List, Optional
 from uuid import UUID
 
-from gable.openapi import ContractSpec, ContractStatus, EnforcementLevel
 from pydantic import BaseModel
 
+from gable.openapi import ContractSpec, ContractStatus, EnforcementLevel
+
 
 # https://trino.io/docs/current/language/types.html
 class TrinoDataType(str, Enum):
@@ -86,11 +87,11 @@ class GitMetadata(BaseModel):
 
 
 class ExternalContractInput(BaseModel):
-    version: Optional[str]
+    version: Optional[str] = None
     status: ContractStatus
-    enforcementLevel: Optional[EnforcementLevel]
+    enforcementLevel: Optional[EnforcementLevel] = None
     contractSpec: ContractSpec
-    gitMetadata: Optional[GitMetadata]
+    gitMetadata: Optional[GitMetadata] = None
 
 
 class ContractPublishResponse(BaseModel):
